/**
 * Note: 路由配置项
 *
 * path: '/path'                    // 路由路径
 * name:'router-name'               // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * meta : {
    title: 'title'                  // 设置该路由在侧边栏的名字
    icon: 'icon-name'                // 设置该路由的图标
    activeMenu: '/system/user'      // 当路由设置了该属性，则会高亮相对应的侧边栏。
    query: '{"id": 1}'             // 访问路由的默认传递参数
    hidden: true                   // 当设置 true 的时候该路由不会在侧边栏出现 
    hideTab: true                   //当设置 true 的时候该路由不会在多标签tab栏出现
  }
 */

import type { RouteRecordRaw } from 'vue-router'
import { PageEnum } from '@/enums/pageEnum'
import Layout from '@/layout/index.vue'

export const LAYOUT = () => Promise.resolve(Layout)

export const INDEX_ROUTE_NAME = Symbol()

export const constantRoutes: Array<RouteRecordRaw> = [
    {
        path: PageEnum.ERROR_404,
        component: () => import('@/views/error/404.vue')
    },
    {
        path: PageEnum.ERROR_403,
        component: () => import('@/views/error/403.vue')
    },
    {
        path: PageEnum.LOGIN,
        component: () => import('@/views/account/login.vue')
    },
    {
        path: '/dev_tools',
        component: LAYOUT,
        children: [
            {
                path: 'code/edit',
                component: () => import('@/views/dev_tools/code/edit.vue'),
                meta: {
                    title: '编辑数据表',
                    activeMenu: '/dev_tools/code'
                }
            }
        ]
    },
    {
        path: '/setting',
        component: LAYOUT,
        children: [
            {
                path: 'dict/data',
                component: () => import('@/views/setting/dict/data/index.vue'),
                meta: {
                    title: '数据管理',
                    activeMenu: '/setting/dict'
                }
            },
            {
                path: 'system/task/edit',
                component: () => import('@/views/setting/system/task/edit.vue'),
                meta: {
                    title: '新增任务',
                    activeMenu: '/setting/system/task'
                }
            }
        ]
    },
    {
        path: '/setting',
        component: LAYOUT,
        children: [
            {
                path: 'dict/data',
                component: () => import('@/views/setting/dict/data/index.vue'),
                meta: {
                    title: '数据管理',
                    activeMenu: '/setting/dict'
                }
            }
        ]
    },
    {
        path: '/order',
        component: LAYOUT,
        children: [
            {
                path: 'lists/detail',
                component: () => import('@/views/order/lists/detail.vue'),
                meta: {
                    title: '订单列表',
                    activeMenu: '/order/lists'
                }
            }
        ]
    },
    {
        path: '/material',
        component: LAYOUT,
        children: [
            {
                path: '/material/receive/detail',
                component: () => import('@/views/material/receive/detail.vue'),
                meta: {
                    title: '配件领用审核',
                    activeMenu: '/material/receive'
                }
            },
            {
                path: '/material/receive/send',
                component: () => import('@/views/material/receive/send.vue'),
                meta: {
                    title: '配件领用发送物流',
                    activeMenu: '/material/receive'
                }
            },
            {
                path: '/material/allot/edit',
                component: () => import('@/views/material/allot/edit.vue'),
                meta: {
                    title: '配件调拨表单',
                    activeMenu: '/material/allot'
                }
            },
            {
                path: '/material/allot/detail',
                component: () => import('@/views/material/allot/detail.vue'),
                meta: {
                    title: '配件调拨详情',
                    activeMenu: '/material/allot'
                }
            },
            {
                path: '/material/outOfStock/edit',
                component: () => import('@/views/material/outOfStock/edit.vue'),
                meta: {
                    title: '配件出库表单',
                    activeMenu: '/material/outOfStock'
                }
            },
            {
                path: '/material/outOfStock/detail',
                component: () => import('@/views/material/outOfStock/detail.vue'),
                meta: {
                    title: '配件出库详情',
                    activeMenu: '/material/outOfStock'
                }
            },
            {
                path: '/material/warehousing/edit',
                component: () => import('@/views/material/warehousing/edit.vue'),
                meta: {
                    title: '配件入库表单',
                    activeMenu: '/material/warehousing'
                }
            },
            {
                path: '/material/warehousing/detail',
                component: () => import('@/views/material/warehousing/detail.vue'),
                meta: {
                    title: '配件入库详情',
                    activeMenu: '/material/warehousing'
                }
            },
            {
                path: '/material/audit/audit',
                component: () => import('@/views/material/audit/audit.vue'),
                meta: {
                    title: '配件出入库审核表单',
                    activeMenu: '/material/audit'
                }
            },
            {
                path: '/material/purchaseOrder/detail',
                component: () => import('@/views/material/purchaseOrder/detail.vue'),
                meta: {
                    title: '配件采购审核',
                    activeMenu: '/material/purchaseOrder'
                }
            },
            {
                path: '/material/purchaseOrder/send',
                component: () => import('@/views/material/purchaseOrder/send.vue'),
                meta: {
                    title: '配件采购发送物流',
                    activeMenu: '/material/purchaseOrder'
                }
            },
            {
                path: '/material/purchase/add',
                component: () => import('@/views/material/purchase/add.vue'),
                meta: {
                    title: '配件采购新建',
                    activeMenu: '/material/purchase'
                }
            },
            {
                path: '/material/purchase/detail',
                component: () => import('@/views/material/purchase/detail.vue'),
                meta: {
                    title: '配件采购详情',
                    activeMenu: '/material/purchase'
                }
            }
        ]
    }
]

export const INDEX_ROUTE: RouteRecordRaw = {
    path: PageEnum.INDEX,
    component: LAYOUT,
    name: INDEX_ROUTE_NAME
}
